/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IInterceptorBinding.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element interceptor-binding.
 * @author Florent Benoit

 */
public interface IInterceptorBinding extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "interceptor-binding";

    /**
     * @return the name of the EJB.
     */
    String getEjbName();

    /**
     * Sets the name of this ejb (or wildcard).
     * @param ejbName the name of the ejb.
     */
    void setEjbName(final String ejbName);

    /**
     * @return the method element
     */
    IMethodDD getMethod();

    /**
     * Method on which define the interceptors.
     * @param method the given method.
     */
    void setMethod(final IMethodDD method);

    /**
     * @return true if the class interceptors are excluded for the given method
     */
    boolean isExcludeClassInterceptors();

    /**
     * Exclude or not class interceptors ?
     * @param excludeClassInterceptors true/false
     */
    void setExcludeClassInterceptors(final boolean excludeClassInterceptors);

    /**
     * @return true if method setExcludeClassInterceptors has been called (with false or true)
     */
    boolean isExcludeClassInterceptorsCalled();

    /**
     * @return true if the default interceptors are excluded for the given bean
     */
    boolean isExcludeDefaultInterceptors();

    /**
     * Exclude or not default interceptors ?
     * @param excludeDefaultInterceptors true/false
     */
    void setExcludeDefaultInterceptors(final boolean excludeDefaultInterceptors);

    /**
     * @return true if method setExcludeDefaultInterceptors has been called (with false or true)
     */
    boolean isExcludeDefaultInterceptorsCalled();

    /**
     * @return list of the interceptor classes.
     */
    List<String> getInterceptorClassList();

    /**
     * @return list of ordered interceptor classes.
     */
    List<String> getOrderInterceptorClassList();

    /**
     * Add the given interceptor to the list.
     * @param interceptorClassName the name of the interceptor's class
     */
    void addInterceptorClass(final String interceptorClassName);

    /**
     * Add the given interceptor to the ordered list.
     * @param interceptorClassName the name of the interceptor's class
     */
    void addOrderedInterceptorClass(final String interceptorClassName);

}
